==> manaplus_1.4.3.15.orig.tar.xz: manaplus-1.4.3.15/src/gui/rect.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2011-2014  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/*      _______   __   __   __   ______   __   __   _______   __   __
 *     / _____/\ / /\ / /\ / /\ / ____/\ / /\ / /\ / ___  /\ /  |\/ /\
 *    / /\____\// / // / // / // /\___\// /_// / // /\_/ / // , |/ / /
 *   / / /__   / / // / // / // / /    / ___  / // ___  / // /| ' / /
 *  / /_// /\ / /_// / // / // /_/_   / / // / // /\_/ / // / |  / /
 * /______/ //______/ //_/ //_____/\ /_/ //_/ //_/ //_/ //_/ /|_/ /
 * \______\/ \______\/ \_\/ \_____\/ \_\/ \_\/ \_\/ \_\/ \_\/ \_\/
 *
 * Copyright (c) 2004 - 2008 Olof Naessén and Per Larsson
 *
 *
 * Per Larsson a.k.a finalman
 * Olof Naessén a.k.a jansem/yakslem
 *
 * Visit: http://guichan.sourceforge.net
 *
 * License: (BSD)
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 3. Neither the name of Guichan nor the names of its contributors may
 *    be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef GUI_RECT_H
#define GUI_RECT_H

#include <iostream>

#include "localconsts.h"

/**
  * Represents a rectangle.
  *
  * @since 0.1.0
  */
class Rect
{
    public:
        /**
          * Constructor. The default rectangle is an empty rectangle
          * at the coordinates (0,0).
          */
        Rect();

        /**
          * Constructor.
          *
          * @param x The x coordinate of the rectangle.
          * @param y The y coordinate of the rectangle.
          * @param width The width of the rectangle.
          * @param height The height of the rectangle.
          * @since 0.1.0
          */
        Rect(const int x, const int y, const int width, const int height);

        virtual ~Rect()
        { }

        /**
          * Sets the dimension of a rectangle.
          *
          * @param x The x coordinate of the rectangle.
          * @param y The y coordinate of the rectangle.
          * @param width The width of the rectangle.
          * @param height The height of the rectangle.
          * @since 0.1.0
          */
        void setAll(const int x,
                    const int y,
                    const int width0,
                    const int height0);

        /**
          * Checks if another rectangle intersects with the rectangle.
          *
          * @param rectangle Another rectangle to check for intersection.
          * @return True if the rectangles intersect, false otherwise.
          * @since 0.1.0
          */
        bool isIntersecting(const Rect& rectangle) const A_WARN_UNUSED;

        /**
          * Checks if a point is inside the rectangle
          *
          * @param x The x coordinate of the point.
          * @param y The y coordinate of the point.
          * @return True if the point is inside the rectangle.
          * @since 0.1.0
          */
        bool isPointInRect(int x, int y) const A_WARN_UNUSED;

        /**
          * Output operator for output.
          *
          * @param out The stream to output to.
          * @param rectangle The rectangle to output.
          */
        friend std::ostream& operator<<(std::ostream& out,
                                        const Rect& rectangle);

        /**
          * Holds the x coordinate of the rectangle.
          */
        int x;

        /**
          * Holds the x coordinate of the rectangle.
          */
        int y;

        /**
          * Holds the width of the rectangle.
          */
        int width;

        /**
          * Holds the height of the rectangle.
          */
        int height;
};

#endif  // GUI_RECT_H

==> manaplus_1.4.3.29.orig.tar.xz: manaplus-1.4.3.29/src/gui/rect.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2011-2014  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/*      _______   __   __   __   ______   __   __   _______   __   __
 *     / _____/\ / /\ / /\ / /\ / ____/\ / /\ / /\ / ___  /\ /  |\/ /\
 *    / /\____\// / // / // / // /\___\// /_// / // /\_/ / // , |/ / /
 *   / / /__   / / // / // / // / /    / ___  / // ___  / // /| ' / /
 *  / /_// /\ / /_// / // / // /_/_   / / // / // /\_/ / // / |  / /
 * /______/ //______/ //_/ //_____/\ /_/ //_/ //_/ //_/ //_/ /|_/ /
 * \______\/ \______\/ \_\/ \_____\/ \_\/ \_\/ \_\/ \_\/ \_\/ \_\/
 *
 * Copyright (c) 2004 - 2008 Olof Naessén and Per Larsson
 *
 *
 * Per Larsson a.k.a finalman
 * Olof Naessén a.k.a jansem/yakslem
 *
 * Visit: http://guichan.sourceforge.net
 *
 * License: (BSD)
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 3. Neither the name of Guichan nor the names of its contributors may
 *    be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef GUI_RECT_H
#define GUI_RECT_H

#include "localconsts.h"

/**
  * Represents a rectangle.
  *
  * @since 0.1.0
  */
class Rect
{
    public:
        /**
          * Constructor. The default rectangle is an empty rectangle
          * at the coordinates (0,0).
          */
        Rect();

        /**
          * Constructor.
          *
          * @param x The x coordinate of the rectangle.
          * @param y The y coordinate of the rectangle.
          * @param width The width of the rectangle.
          * @param height The height of the rectangle.
          * @since 0.1.0
          */
        Rect(const int x, const int y, const int width, const int height);

        virtual ~Rect()
        { }

        /**
          * Sets the dimension of a rectangle.
          *
          * @param x The x coordinate of the rectangle.
          * @param y The y coordinate of the rectangle.
          * @param width The width of the rectangle.
          * @param height The height of the rectangle.
          * @since 0.1.0
          */
        void setAll(const int x,
                    const int y,
                    const int width0,
                    const int height0);

        /**
          * Checks if another rectangle intersects with the rectangle.
          *
          * @param rectangle Another rectangle to check for intersection.
          * @return True if the rectangles intersect, false otherwise.
          * @since 0.1.0
          */
        bool isIntersecting(const Rect& rectangle) const A_WARN_UNUSED;

        /**
          * Checks if a point is inside the rectangle
          *
          * @param x The x coordinate of the point.
          * @param y The y coordinate of the point.
          * @return True if the point is inside the rectangle.
          * @since 0.1.0
          */
        bool isPointInRect(const int x, const int y) const A_WARN_UNUSED;

        /**
          * Holds the x coordinate of the rectangle.
          */
        int x;

        /**
          * Holds the x coordinate of the rectangle.
          */
        int y;

        /**
          * Holds the width of the rectangle.
          */
        int width;

        /**
          * Holds the height of the rectangle.
          */
        int height;
};

#endif  // GUI_RECT_H
